.. _install:

Installation
============

Stable Release
--------------

To install the stable release version of fRAGme, run the following command:

.. code-block:: bash

    pip install fRAGme

Bleeding-edge version
---------------------

To install the latest master version:

.. code-block:: bash

	pip install git+https://github.com/fRAGme/fRAGme.git
